Camelot Installation — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot Documentation contents »
- Camelot Documentation »

# Camelot Installation

## All in one Windows installer

When working on Windows, the easiest way to get up and running is through the Conceptive Python SDK.

This SDK is a Python distribution targeted at the development and deployment of QT based applications. This all in one installation of Camelot with all its dependencies is available in the shop.

## From the Python Package Index

First, make sure you have setup tools installed, Setup tools. If you are using a debian based distribution, you can type:

    sudo apt-get install python-setuptools

Then use easy_install to install Camelot, under Linux this would be done by typing:

    sudo easy_install camelot

## Packages

Linux distributions often offer packages for various applications, including Camelot and its dependencies :

> - OpenSUSE build service.

## From source

When installing Camelot from source, you need to make sure all dependencies are installed and available in your PYTHONPATH.

Dependencies

Notice that bugs in QT 4.6 and PyQt 4.7 may cause a Camelot application to crash, so newer versions of those libraries are required.

> - QT 4.7
> - PyQt 4.8 PyQt Website
> - SQLAlchemy 0.6.5 SQLAlchemy Website
> - Elixir 0.7.1 Elixir Website
> - sqlalchemy-migrate 0.7.1
> - Jinja2 2.5.5
> - chardet 1.0.1
> - xlwt 0.7.2
> - xlrd 0.5.2

Releases

The source code of a release can be downloaded from the Python Package Index and then extracted:

    tar xzvf Camelot-10.07.02.tar.gz

Trunk

The latest and greatest version of the source can be checked out from the subversion repository:

    svn co http://guest:guest@repository.conceptive.be/camelot/svn/trunk/

Adapting PYTHONPATH

You need to make sure Camelot and all its dependencies are in the PYTHONPATH before you start using it:

    export PYTHONPATH=/home/username/Camelot-10.07.02

or:

    export PYTHONPATH=/home/username/Camelot-10.07.02:path to sqlalchemy:path to elxir:...

## Verifiy the installation

To verify if you have Camelot installed and available in the PYTHONPATH, fire up a python interpreter:

    python

and issue these commands:

    >>> import camelot
    >>> print camelot.__version__
    >>> import sqlalchemy
    >>> print sqlalchemy.__version__
    >>> import elixir
    >>> print elixir.__version__
    >>> import PyQt4

None of them should raise an ImportError.

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot Documentation contents »
- Camelot Documentation »

Comments
blog comments powered by Disqus